summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDivya Sasidharan <divya.s.sasidharan@intel.com>2021-09-23 23:18:48 -0700
committerCommit Bot <commit-bot@chromium.org>2021-10-05 00:57:59 +0000
commit771b5ff866e0ef006924952d19b6065496c43ab0 (patch)
treeaa0b009e5d126f7aca0bf1cffe686c26dffe6a52
parent79d8c7d2c15083f2fc4c07e4e2816a02b363fb41 (diff)
downloadchrome-ec-771b5ff866e0ef006924952d19b6065496c43ab0.tar.gz
power/alderlake: Cleanup code to use common GPIO name
SEQ_EC_ALL_SYS_PG is commonly named as PG_EC_ALL_SYS_PWRGD. Removing it to reduce the redundant declarations needed in zephyr. BUG=b:200975143 BRANCH=main TEST=make buildall -j; boot up brya Change-Id: Ie266460dfe9c61dbbb97e1d1b714824929c5a098 Signed-off-by: Divya Sasidharan <divya.s.sasidharan@intel.com> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/3180807 Reviewed-by: Vijay Hiremath <vijay.p.hiremath@intel.com> Reviewed-by: caveh jalali <caveh@chromium.org> Reviewed-by: Keith Short <keithshort@chromium.org> Commit-Queue: Keith Short <keithshort@chromium.org>
-rw-r--r--power/alderlake_slg4bd44540.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/power/alderlake_slg4bd44540.c b/power/alderlake_slg4bd44540.c
index e7ae9497a2..381b86bd1e 100644
--- a/power/alderlake_slg4bd44540.c
+++ b/power/alderlake_slg4bd44540.c
@@ -23,13 +23,13 @@
* should be suitable for variants.
*/
/* SEQ_EC_ALL_SYS_PG high to VCCST_PWRGD high delay */
#define VCCST_PWRGD_DELAY_MS 2
/* IMVP9_VRRDY high to PCH_PWROK high delay */
#define PCH_PWROK_DELAY_MS 2
/* SEQ_EC_ALL_SYS_PG high to EC_PCH_SYS_PWROK high delay */
#define SYS_PWROK_DELAY_MS 45
/* IMVP9_VRRDY high timeout */
@@ -188,17 +188,17 @@ static void all_sys_pwrgd_pass_thru(void)
int pch_pok;
int sys_pok;
- sys_pg = gpio_get_level(GPIO_SEQ_EC_ALL_SYS_PG);
+ sys_pg = gpio_get_level(GPIO_PG_EC_ALL_SYS_PWRGD);
if (IS_ENABLED(CONFIG_BRINGUP))
- CPRINTS("SEQ_EC_ALL_SYS_PG is %d", sys_pg);
+ CPRINTS("PG_EC_ALL_SYS_PWRGD is %d", sys_pg);
if (sys_pg == 0) {
ap_off();
return;
}
/* SEQ_EC_ALL_SYS_PG is asserted, enable VCCST_PWRGD_OD. */
vccst_pg = gpio_get_level(GPIO_VCCST_PWRGD_OD);
if (vccst_pg == 0) {
@@ -226,9 +226,9 @@ static void all_sys_pwrgd_pass_thru(void)
if (sys_pok == 0) {
msleep(SYS_PWROK_DELAY_MS);
/* Check if we lost power while waiting. */
- sys_pg = gpio_get_level(GPIO_SEQ_EC_ALL_SYS_PG);
+ sys_pg = gpio_get_level(GPIO_PG_EC_ALL_SYS_PWRGD);
if (sys_pg == 0) {
- CPRINTS("SEQ_EC_ALL_SYS_PG deasserted, "
+ CPRINTS("PG_EC_ALL_SYS_PWRGD deasserted, "
"shutting AP off!");
ap_off();
return;
@@ -23,13 +23,13 @@
* should be suitable for variants.
*/
-/* SEQ_EC_ALL_SYS_PG high to VCCST_PWRGD high delay */
+/* PG_EC_ALL_SYS_PWRGD high to VCCST_PWRGD high delay */
#define VCCST_PWRGD_DELAY_MS 2
/* IMVP9_VRRDY high to PCH_PWROK high delay */
@@ -23,13 +23,13 @@
/* IMVP9_VRRDY high to PCH_PWROK high delay */
#define PCH_PWROK_DELAY_MS 2
-/* SEQ_EC_ALL_SYS_PG high to EC_PCH_SYS_PWROK high delay */
+/* PG_EC_ALL_SYS_PWRGD high to EC_PCH_SYS_PWROK high delay */
#define SYS_PWROK_DELAY_MS 45
/* IMVP9_VRRDY high timeout */
@@ -188,17 +188,17 @@ static void all_sys_pwrgd_pass_thru(void)
return;
}
- /* SEQ_EC_ALL_SYS_PG is asserted, enable VCCST_PWRGD_OD. */
+ /* PG_EC_ALL_SYS_PWRGD is asserted, enable VCCST_PWRGD_OD. */
vccst_pg = gpio_get_level(GPIO_VCCST_PWRGD_OD);
if (vccst_pg == 0) {